[cl-unification-cvs] CVS cl-unification

rbrown rbrown at common-lisp.net
Fri Feb 11 17:49:39 UTC 2011


Update of /project/cl-unification/cvsroot/cl-unification
In directory cl-net:/tmp/cvs-serv12304

Modified Files:
	templates-hierarchy.lisp unification-package.lisp unifier.lisp 
Log Message:
Use *unify-string-case-sensitive-p* consistently.
Change the documentation.
templates-hierarchy.lisp: Fix stream argument to print-object.

--- /project/cl-unification/cvsroot/cl-unification/templates-hierarchy.lisp	2009/12/17 16:43:12	1.6
+++ /project/cl-unification/cvsroot/cl-unification/templates-hierarchy.lisp	2011/02/11 17:49:38	1.7
@@ -106,7 +106,7 @@
   (:method ((x t)) nil))
 
 
-(defmethod print-object ((template template) (stream stream))
+(defmethod print-object ((template template) stream)
   (format stream "#T~S" (template-spec template)))
 
 
--- /project/cl-unification/cvsroot/cl-unification/unification-package.lisp	2009/12/17 16:43:51	1.7
+++ /project/cl-unification/cvsroot/cl-unification/unification-package.lisp	2011/02/11 17:49:38	1.8
@@ -21,7 +21,7 @@
    "TEMPLATE-SPEC")
 
   (:export
-   "*UNIFY-STRING-CASE-INSENSITIVE-P*"
+   "*UNIFY-STRING-CASE-SENSITIVE-P*"
    "UNIFY"
    "FIND-VARIABLE-VALUE"
    "V?"
--- /project/cl-unification/cvsroot/cl-unification/unifier.lisp	2011/01/18 14:50:17	1.8
+++ /project/cl-unification/cvsroot/cl-unification/unifier.lisp	2011/02/11 17:49:38	1.9
@@ -91,7 +91,7 @@
 Two CHARACTERs A and B unify if and only if they satisfy either #'CHAR= or
 #'CHAR-EQUAL. The choice of which of test to perform (#'CHAR= or #'CHAR-EQUAL)
 is made according to the value of the variable
 *UNIFY-STRING-CASE-INSENSITIVE-P*, which defaults to NIL.
 If A and B unify then an unmodified environment ENV is returned,
 otherwise an error of type UNIFICATION-FAILURE is signaled."
   (cond ((and case-sensitive (char= a b))
@@ -113,12 +113,12 @@
 Two strings A and B unify if and only if they satisfy either #'STRING= or
 #'STRING-EQUAL. The choice of which of test to perform (#'STRING= or #'STRING-EQUAL)
 is made according to the value of the variable
 *UNIFY-STRING-CASE-INSENSITIVE-P*, which defaults to NIL.
 If A and B unify then an unmodified environment ENV is returned,
 otherwise an error of type UNIFICATION-FAILURE is signaled."
   (cond ((and case-sensitive (string= a b))
          env)
-        ((string-equal a b)
+        ((and (not case-sensitive) (string-equal a b))
          env)
         (t
          (error 'unification-failure
@@ -91,7 +91,7 @@
 #'CHAR-EQUAL. The choice of which of test to perform (#'CHAR= or #'CHAR-EQUAL)
 is made according to the value of the variable
-*UNIFY-STRING-CASE-INSENSITIVE-P*, which defaults to NIL.
+*UNIFY-STRING-CASE-SENSITIVE-P*, which defaults to T.
 If A and B unify then an unmodified environment ENV is returned,
 otherwise an error of type UNIFICATION-FAILURE is signaled."
@@ -113,12 +113,12 @@
 #'STRING-EQUAL. The choice of which of test to perform (#'STRING= or #'STRING-EQUAL)
 is made according to the value of the variable
-*UNIFY-STRING-CASE-INSENSITIVE-P*, which defaults to NIL.
+*UNIFY-STRING-CASE-SENSITIVE-P*, which defaults to T.
 If A and B unify then an unmodified environment ENV is returned,
 otherwise an error of type UNIFICATION-FAILURE is signaled."





More information about the Cl-unification-cvs mailing list